==> osb-nrcore-0.5.0.tar.gz: osb-nrcore-0.5.0/kwiq/KWQDictImpl.h <==
/*
 * Copyright (C) 2003 Apple Computer, Inc.  All rights reserved.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions
 * are met:
 * 1. Redistributions of source code must retain the above copyright
 *    notice, this list of conditions and the following disclaimer.
 * 2. Redistributions in binary form must reproduce the above copyright
 *    notice, this list of conditions and the following disclaimer in the
 *    documentation and/or other materials provided with the distribution.
 *
 * THIS SOFTWARE IS PROVIDED BY APPLE COMPUTER, INC. ``AS IS'' AND ANY
 * EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
 * IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR
 * PURPOSE ARE DISCLAIMED.  IN NO EVENT SHALL APPLE COMPUTER, INC. OR
 * CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL,
 * EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO,
 * PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR
 * PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY
 * OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT
 * (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE
 * OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE. 
 */

#ifndef KWQ_DICT_IMPL_H
#define KWQ_DICT_IMPL_H

#include "KWQMap.h"
#include "KWQString.h"

class KWQDictImpl {
 public:
    KWQDictImpl(int size, bool caseSensitive, void (*deleteFunc)(void *));
    void insert(const QString &key, const void *value);
    bool remove(const QString &key, bool deleteItems);
    
    void *find(const QString &key) const;
    void clear(bool deleteItem);
    uint count() const;
 private:
    void (*deleteFunc)(void*);
    QMap<QString,void*> map;
    bool modifyCase;
    friend class KWQDictIteratorImpl;
};

class KWQDictIteratorImpl {
    const KWQDictImpl *dict;
    QMapConstIterator<QString,void*> i;
 public:
    KWQDictIteratorImpl(const KWQDictImpl &di) :dict(&di), i(di.map.begin()) { }
    uint count() const ;
    void *current() const;

    void* toFirst();

    void *operator++();


    QString currentStringKey() const;
};

#endif

==> osb-nrcore_0.5.1-1.tar.gz: osb-nrcore-0.5.1/kwiq/KWQDictImpl.h <==
/*
 * Copyright (C) 2003 Apple Computer, Inc.  All rights reserved.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions
 * are met:
 * 1. Redistributions of source code must retain the above copyright
 *    notice, this list of conditions and the following disclaimer.
 * 2. Redistributions in binary form must reproduce the above copyright
 *    notice, this list of conditions and the following disclaimer in the
 *    documentation and/or other materials provided with the distribution.
 *
 * THIS SOFTWARE IS PROVIDED BY APPLE COMPUTER, INC. ``AS IS'' AND ANY
 * EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
 * IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR
 * PURPOSE ARE DISCLAIMED.  IN NO EVENT SHALL APPLE COMPUTER, INC. OR
 * CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL,
 * EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO,
 * PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR
 * PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY
 * OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT
 * (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE
 * OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE. 
 */

#ifndef KWQ_DICT_IMPL_H
#define KWQ_DICT_IMPL_H

#include "KWQMap.h"
#include "KWQString.h"

class KWQDictPrivate;
class KWQDictIteratorPrivate;

class KWQDictImpl {
 public:
    KWQDictImpl(int size, bool caseSensitive, void (*deleteFunc)(void *));
    ~KWQDictImpl();
    void insert(const QString &key, const void *value);
    bool remove(const QString &key, bool deleteItems);
    
    void *find(const QString &key) const;
    void clear(bool deleteItem);
    uint count() const;

    KWQDictImpl &assign(const KWQDictImpl &pdi, bool deleteItems);
private:
    void swap(KWQDictImpl &di);
    KWQDictPrivate *d;
    friend class KWQDictIteratorImpl;
};

class KWQDictIteratorImpl {
 public:
    KWQDictIteratorImpl(const KWQDictImpl &di);
    uint count() const ;
    void *current() const;

    void* toFirst();

    void *operator++();


    QString currentStringKey() const;
private:
    KWQDictIteratorPrivate *d;

};

#endif
